package com.fs.hisStore.service;

import com.fs.his.domain.FsUserAddress;
import com.fs.hisStore.domain.FsUserAddressScrm;

import java.util.List;

/**
 * 用户地址Service接口
 *
 * @author fs
 * @date 2022-03-15
 */
public interface IFsUserAddressScrmService
{
    /**
     * 查询用户地址
     *
     * @param id 用户地址ID
     * @return 用户地址
     */
    public FsUserAddressScrm selectFsUserAddressById(Long id);

    /**
     * 查询用户地址列表
     *
     * @param fsUserAddress 用户地址
     * @return 用户地址集合
     */
    public List<FsUserAddressScrm> selectFsUserAddressList(FsUserAddressScrm fsUserAddress);

    /**
     * 新增用户地址
     *
     * @param fsUserAddress 用户地址
     * @return 结果
     */
    public int insertFsUserAddress(FsUserAddressScrm fsUserAddress);

    /**
     * 修改用户地址
     *
     * @param fsUserAddress 用户地址
     * @return 结果
     */
    public int updateFsUserAddress(FsUserAddressScrm fsUserAddress);

    /**
     * 批量删除用户地址
     *
     * @param ids 需要删除的用户地址ID
     * @return 结果
     */
    public int deleteFsUserAddressByIds(Long[] ids);

    /**
     * 删除用户地址信息
     *
     * @param id 用户地址ID
     * @return 结果
     */
    public int deleteFsUserAddressById(Long id);

    int clearIsDefalut(long userId);

    Integer selectFsUserAddressCountsByUserId(long userId);

    Integer delAllAddress(Long userId);

    String getKdnAddress(String address);

    FsUserAddress selectFsUserAddressByDefault(long l);
}
